autowisp.database.initialize_data_reduction_structure module — AutoWISP documentation

# autowisp.database.initialize_data_reduction_structure module

## Class Inheritance Diagram

Define function to add defaults to all HDF5 structure tables.

autowisp.database.initialize_data_reduction_structure._get_apphot_attributes()

  Create default data reduction attributes describing aperture photometry.

autowisp.database.initialize_data_reduction_structure._get_apphot_datasets()

  Create the datasets to contain shape aperture photometry results.

autowisp.database.initialize_data_reduction_structure._get_apphot_links()

  Create default data reduction links for sky to background extraction.

autowisp.database.initialize_data_reduction_structure._get_attributes()

  Create the default database attributes in data reduction HDF5 files.

autowisp.database.initialize_data_reduction_structure._get_background_attributes()

  Create default attributes in data reduction files describing BG extraction.

autowisp.database.initialize_data_reduction_structure._get_background_datasets()

  Create default data reduction data sets of background measurements.

autowisp.database.initialize_data_reduction_structure._get_background_links()

  Create default data reduction links for sky to background extraction.

autowisp.database.initialize_data_reduction_structure._get_catalogue_attributes()

  Create default data reduction attributes describing catalogue queries.

autowisp.database.initialize_data_reduction_structure._get_catalogue_datasets()

  Create default data reduction datasets for catalogue_queries.

autowisp.database.initialize_data_reduction_structure._get_datasets()

  Create the default database datasets in data reduction HDF5 files.

autowisp.database.initialize_data_reduction_structure._get_link(used_component, user_component, description)

  Return link to one version of used_component within user_component group.

  Parameters:

    - used_component – The pipeline name of the component being used.

    - user_component – The pipeline component using used_component.

    - description – A description of the link.

  Returns:

    A properly constructed link signifying that user_component was derived based on a particular version of used_component.

  Return type:

    autowisp.database.data_model.HDF5Link

autowisp.database.initialize_data_reduction_structure._get_links()

  Create the default database links in data reduction HDF5 files.

autowisp.database.initialize_data_reduction_structure._get_magfit_attributes(photometry_mode)

  Return a set of magnitude fitting attributes for a single photometry.

  Parameters:

    photometry_mode (str) – The method by which the raw magnitudes used for magnitude fitting were extracted.

  Returns:

    The attributes describing magnitude fitting.

  Return type:

    [autowisp.database.data_model.HDF5Attribute]

autowisp.database.initialize_data_reduction_structure._get_magfit_datasets(photometry_mode)

  Return a set of magnitude fitting data sets for a single photometry.

  Parameters:

    photometry_mode (str) – The method by which the raw magnitudes used for magnitude fitting were extracted.

  Returns:

    The datasets containing the magnitude fitting results.

  Return type:

    [autowisp.database.data_model.HDF5DataSet]

autowisp.database.initialize_data_reduction_structure._get_magfit_key_and_path(photometry_mode)

  Return start of pipeline key and path for magfit datasets/attributes.

  Parameters:

    photometry_mode (str) – The method by which the raw magnitudes used for magnitude fitting were extracted.

  Returns:

    The start of the pipeline_key and the absolute path of the dataset in the HDF5 file under whihc to place the fitted magnitudes and associated attributes.

  Return type:

    str, str

autowisp.database.initialize_data_reduction_structure._get_shapefit_attributes()

  Create the default attribute in data reduction files describing PSF fitting.

  Parameters:

    None

  Returns:

    All attributes related to PSF/PRF fitting to include in data reduction files.

  Return type:

    [autowisp.database.data_model.HDF5Attribute]

autowisp.database.initialize_data_reduction_structure._get_shapefit_datasets()

  Create the datasets to contain shape fitting results.

autowisp.database.initialize_data_reduction_structure._get_shapefit_links()

  Create default data reduction links for sky to background extraction.

autowisp.database.initialize_data_reduction_structure._get_sky_to_frame_datasets()

  Create default data reduction sky to frame transformation data sets.

autowisp.database.initialize_data_reduction_structure._get_sky_to_frame_links()

  Create default data reduction links for sky to frame transformations.

autowisp.database.initialize_data_reduction_structure._get_skytoframe_attributes()

  Create default data reduction attributes describing the astrometry.

autowisp.database.initialize_data_reduction_structure._get_source_extraction_attributes()

  Create default data reduction attributes describing source extraction.

autowisp.database.initialize_data_reduction_structure._get_source_extraction_datasets()

  Create default data reduction datesets for source extraction.

autowisp.database.initialize_data_reduction_structure._get_source_projection_attributes()

  Create default data reduction attributes describing source projection.

autowisp.database.initialize_data_reduction_structure._get_source_projection_datasets()

  Create default projected sources data reduction data sets.

autowisp.database.initialize_data_reduction_structure._get_source_projection_links()

  Create default data reduction links for projected sources.

autowisp.database.initialize_data_reduction_structure.get_default_data_reduction_structure()

  Add the default configuration for the layout of data reduction files.